"use client";

import { consumersRequestList } from "@/app/lib/consumers/action";
import { getStorage, setStorage } from "@/utils/navigation";
import { Box } from "@chakra-ui/react";
import { useEffect, useState, useCallback } from "react";
import CardList from "./components/card-list";
import { CardListProps } from "../kycs/components/card-list";

export interface ConsumerData {
  last_sync_at: string;
  data: CardListProps[];
}

const Page = () => {
  const [data, setData] = useState([]);
  const [loading, setLoading] = useState<boolean>(false);

  const handleSync = useCallback(async () => {
    setLoading(true);
    setStorage("consumers", null);
    try {
      const res = await consumersRequestList({ pagination: "false" });
      const consumersData: ConsumerData = {
        last_sync_at: new Date().toISOString(),
        data: res?.data || [],
      };

      setStorage("consumers", consumersData);
      setData(consumersData.data);
    } catch (error) {
      console.error("Error syncing consumers:", error);
    } finally {
      setLoading(false);
    }
  }, []);

  useEffect(() => {
    const getAllConsumers = async () => {
      setLoading(true);
      try {
        const storedData = await getStorage("consumers");
        const isDataStale =
          !storedData?.last_sync_at ||
          Date.now() - new Date(storedData.last_sync_at).getTime() > 86400000;

        if (
          (storedData?.data && !isDataStale) ||
          storedData?.data?.some(
            (item: { offline: Boolean }) => item?.offline == true
          )
        ) {
          setData(storedData.data);
        } else {
          await handleSync();
        }
      } catch (error) {
        console.error("Error fetching consumers:", error);
      } finally {
        setLoading(false);
      }
    };

    getAllConsumers();
  }, []);

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      <CardList data={data} isLoading={loading} handleSync={handleSync} />
    </Box>
  );
};

export default Page;
